package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERTaggedObject;

public class KeyAgreeRecipientIdentifier extends ASN1Encodable {
   private IssuerAndSerialNumber issuerSerial;
   private RecipientKeyIdentifier rKeyID;

   private KeyAgreeRecipientIdentifier(ASN1Sequence seq) {
      this.issuerSerial = IssuerAndSerialNumber.getInstance(seq);
      this.rKeyID = null;
   }

   public static KeyAgreeRecipientIdentifier getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static KeyAgreeRecipientIdentifier getInstance(Object obj) {
      if (obj != null && !(obj instanceof KeyAgreeRecipientIdentifier)) {
         if (obj instanceof ASN1Sequence) {
            return new KeyAgreeRecipientIdentifier((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Invalid KeyAgreeRecipientIdentifier: " + obj.getClass().getName());
         }
      } else {
         return (KeyAgreeRecipientIdentifier)obj;
      }
   }

   public KeyAgreeRecipientIdentifier(IssuerAndSerialNumber issuerSerial) {
      this.issuerSerial = issuerSerial;
      this.rKeyID = null;
   }

   public IssuerAndSerialNumber getIssuerAndSerialNumber() {
      return this.issuerSerial;
   }

   public RecipientKeyIdentifier getRKeyID() {
      return this.rKeyID;
   }

   public DERObject toASN1Object() {
      IssuerAndSerialNumber var1;
      if ((var1 = this.issuerSerial) != null) {
         return var1.toASN1Object();
      } else {
         RecipientKeyIdentifier var2 = this.rKeyID;
         return new DERTaggedObject(false, 0, var2);
      }
   }
}
